pub struct MockClientBuilder { /* private fields */ }Available on crate features
testing only.Expand description
An augmented ClientBuilder that also allows for handling session login.
Implementations
Sourceimpl MockClientBuilder
impl MockClientBuilder
Sourcepub fn new(homeserver: Option<&str>) -> Self
pub fn new(homeserver: Option<&str>) -> Self
Create a new MockClientBuilder connected to the given homeserver,
using Matrix V1.12, and which will not attempt any network retry (by
default).
If no homeserver is provided, http://localhost is used as a homeserver.
Sourcepub fn no_server_versions(self) -> Self
pub fn no_server_versions(self) -> Self
Don’t use an initial, cached server versions list in the client.
Sourcepub fn server_versions(self, versions: Vec<MatrixVersion>) -> Self
pub fn server_versions(self, versions: Vec<MatrixVersion>) -> Self
Set the cached server versions in the client.
Sourcepub fn unlogged(self) -> Self
pub fn unlogged(self) -> Self
Doesn’t log-in a user.
Authenticated requests will fail if this is called.
Sourcepub fn registered_with_oauth(self) -> Self
pub fn registered_with_oauth(self) -> Self
The client is registered with the OAuth 2.0 API.
Sourcepub fn logged_in_with_oauth(self) -> Self
pub fn logged_in_with_oauth(self) -> Self
The user is already logged in with the OAuth 2.0 API.
Sourcepub fn logged_in_with_token(
self,
token: String,
user_id: OwnedUserId,
device_id: OwnedDeviceId,
) -> Self
pub fn logged_in_with_token( self, token: String, user_id: OwnedUserId, device_id: OwnedDeviceId, ) -> Self
The user is already logged in with the Matrix Auth.
Sourcepub fn on_builder<F: FnOnce(ClientBuilder) -> ClientBuilder>(self, f: F) -> Self
pub fn on_builder<F: FnOnce(ClientBuilder) -> ClientBuilder>(self, f: F) -> Self
Apply changes to the underlying ClientBuilder.
tokio_test::block_on(async {
use matrix_sdk::test_utils::client::MockClientBuilder;
MockClientBuilder::new(None)
.on_builder(|builder| {
// Here it's possible to modify the underlying `ClientBuilder`.
builder
.handle_refresh_tokens()
.cross_process_store_config(CrossProcessLockConfig::MultiProcess { holder_name: "hodor".to_owned()})
})
.build()
.await;Auto Trait Implementations
impl Freeze for MockClientBuilder
impl !RefUnwindSafe for MockClientBuilder
impl Send for MockClientBuilder
impl Sync for MockClientBuilder
impl Unpin for MockClientBuilder
impl UnsafeUnpin for MockClientBuilder
impl !UnwindSafe for MockClientBuilder